{
    This file is part of SkantiControl

    Skanti TRP8000 series control program (CU8000 control unit)
    This program was developed for a CU8000 control unit marked
    TRP 8255 S R GB1. May work or not with other units.

    Copyright (C) 2012-2022 G. Perotti, I1EPJ, i1epj@aricasale.it

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/.


    Minimum (and wrong) implementation of the dump_caps rigctld command.

    It is only what is returned by rigctld in reply to dump_caps command
    for the TRP8255 S R rig, with some little mods.

    Must be totally rewritten with correct settings if required by some
    program. None of the program tried so far seem to need it. TBD?
}

unit UCapabilities;

{$mode ObjFPC}

interface

uses
  Classes, SysUtils;

var TRP8255_Caps: array[1..193] of string = (
    'Caps dump for model: 14004',
    'Model name:	TRP 8255 S R',
    'Mfg name:	Skanti',
    'Backend version:	20220611.0',
    'Backend copyright:	GPL',
    'Backend status:	Alpha',
    'Rig type:	Transceiver',
    'PTT type:	Rig capable',
    'DCD type:	None',
    'Port type:	RS-232',
    'Serial speed: 300..2400 bauds, 7O1',
    'Write delay: 0mS, timeout 2000mS, 3 retry',
    'Post Write delay: 0mS',
    'Has targetable VFO: N',
    'Has async data support: N',
    'Announce: 0x0',
    'Max RIT: -0.0kHz/+0.0kHz',
    'Max XIT: -0.0kHz/+0.0kHz',
    'Max IF-SHIFT: -0.0kHz/+0.0kHz',
    'Preamp: 10dB',
    'Attenuator: 20dB',
    'AGC levels: 0=OFF 1=SUPERFAST 2=FAST 3=SLOW 4=USER 5=MEDIUM 6=AUTO',
    'CTCSS: None',
    'DCS: None',
    'Get functions:',
    'Set functions: MUTE SQL',
    'Extra functions:',
    'Get level:',
    'Set level: PREAMP(0..0/0) ATT(0..0/0) SQL(0..0/0) RFPOWER(0..0/0) AGC(0..0/0)',
    'Extra levels:',
    'Get parameters:',
    'Set parameters: BACKLIGHT(0..0/0) TIME(0..0/0)',
    'Extra parameters:',
    'Mode list: AM CW USB LSB RTTY',
    'VFO list: VFOA',
    'VFO Ops: CPY FROM_VFO TO_VFO TUNE',
    'Scan Ops:',
    'Number of banks:	0',
    'Memory name desc size:	0',
    'Memories:',
    '	0..76:   	MEM',
    '	  Mem caps: FREQ MODE WIDTH TXFREQ',
    'TX ranges #1 for TBD:',
    'RX ranges #1 for TBD:',
    'TX ranges #2 for TBD:',
    '	2000000 Hz - 30000000 Hz',
    '		VFO list: RX TX',
    '		Mode list: AM',
    '		Antenna list: ANT_NONE',
    '		Low power: 4 W, High power: 40 W',
    ' 	2000000 Hz - 30000000 Hz',
    '		VFO list: RX TX',
    '		Mode list: CW USB LSB RTTY',
    '		Antenna list: ANT_NONE',
    '		Low power: 10 W, High power: 100 W',
    'RX ranges #2 for TBD:',
    '	500000 Hz - 30000000 Hz',
    '		VFO list: RX TX',
    '		Mode list: AM CW USB LSB RTTY',
    '		Antenna list: ANT_NONE',
    'TX ranges #3 for TBD:',
    'RX ranges #3 for TBD:',
    'TX ranges #4 for TBD:',
    'RX ranges #4 for TBD:',
    'TX ranges #5 for TBD:',
    'RX ranges #5 for TBD:',
    'TX ranges #1 status for TBD:	OK (0)',
    'RX ranges #1 status for TBD:	OK (0)',
    'TX ranges #2 status for TBD:	OK (0)',
    'RX ranges #2 status for TBD:	OK (0)',
    'TX ranges #3 status for TBD:	OK (0)',
    'RX ranges #3 status for TBD:	OK (0)',
    'TX ranges #4 status for TBD:	OK (0)',
    'RX ranges #4 status for TBD:	OK (0)',
    'TX ranges #5 status for TBD:	OK (0)',
    'RX ranges #5 status for TBD:	OK (0)',
    'Tuning steps:',
    '	10.0 Hz:   	AM CW USB LSB RTTY',
    '	100.0 Hz:   	AM CW USB LSB RTTY',
    '	1.0000 kHz:   	AM CW USB LSB RTTY',
    'Tuning steps status:	OK (0)',
    'Filters:',
    '	2.7000 kHz:   	AM CW USB LSB',
    '	1.0000 kHz:   	AM CW',
    '	6.0000 kHz:   	AM CW',
    '	250.0 Hz:   	AM RTTY',
    'Bandwidths:',
    '	AM	Normal: 2.7000 kHz, Narrow: 1.0000 kHz,	Wide: 6.0000 kHz',
    '	CW	Normal: 2.7000 kHz, Narrow: 1.0000 kHz,	Wide: 6.0000 kHz',
    '	USB	Normal: 2.7000 kHz, Narrow: 2.1000 kHz,	Wide: 6.0000 kHz',
    '	LSB	Normal: 2.7000 kHz, Narrow: 2.1000 kHz,	Wide: 6.0000 kHz',
    '	RTTY	Normal: 0.25 kHz,   Narrow: 0.0 kHz,	Wide: 0.0 kHz',
    '	FM	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	WFM	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	CWR	Normal: 0.0 kHz,    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	RTTYR	Normal: 0.0 kHz,    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	AMS	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	PKTLSB	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	PKTUSB	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	FM-D	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	ECSSUSB	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	ECSSLSB	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	FAX	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	SAM	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	SAL	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	SAH	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	DSB	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '		Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	FMN	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	AM-D	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	P25	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	D-STAR	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	DPMR	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	NXDN-VN	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	NXDN-N	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	DCR	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	AMN	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    '	PSK	Normal: 0.0 Hz,	    Narrow: 0.0 Hz,	Wide: 0.0 Hz',
    'Spectrum scopes: None',
    'Spectrum modes:',
    'Spectrum spans:',
    'Spectrum averaging modes:',
    'Spectrum attenuator: None',
    'Has priv data:	N',
    'Has Init:	N',
    'Has Cleanup:	N',
    'Has Open:	Y',
    'Has Close:	Y',
    'Can set Conf:	N',
    'Can get Conf:	N',
    'Can set Frequency:	Y',
    'Can get Frequency:	Y',
    'Can set Mode:	Y',
    'Can get Mode:	Y',
    'Can set VFO:	N',
    'Can get VFO:	N',
    'Can set PTT:	Y',
    'Can get PTT:	Y',
    'Can get DCD:	N',
    'Can set Repeater Duplex:	N',
    'Can get Repeater Duplex:	N',
    'Can set Repeater Offset:	N',
    'Can get Repeater Offset:	N',
    'Can set Split Freq:	Y',
    'Can get Split Freq:	Y',
    'Can set Split Mode:	Y',
    'Can get Split Mode:	Y',
    'Can set Split VFO:	Y',
    'Can get Split VFO:	Y',
    'Can set Tuning Step:	Y',
    'Can get Tuning Step:	Y',
    'Can set RIT:	N',
    'Can get RIT:	N',
    'Can set XIT:	N',
    'Can get XIT:	N',
    'Can set CTCSS:	N',
    'Can get CTCSS:	N',
    'Can set DCS:	N',
    'Can get DCS:	N',
    'Can set CTCSS Squelch:	N',
    'Can get CTCSS Squelch:	N',
    'Can set DCS Squelch:	N',
    'Can get DCS Squelch:	N',
    'Can set Power Stat:	N',
    'Can get Power Stat:	N',
    'Can Reset:	N',
    'Can get Ant:	N',
    'Can set Ant:	N',
    'Can set Transceive:	N',
    'Can get Transceive:	N',
    'Can set Func:	Y',
    'Can get Func:	Y',
    'Can set Level:	Y',
    'Can get Level:	Y',
    'Can set Param:	Y',
    'Can get Param:	Y',
    'Can send DTMF:	N',
    'Can recv DTMF:	N',
    'Can send Morse:	N',
    'Can send Voice:	N',
    'Can decode Events:	N',
    'Can set Bank:	N',
    'Can set Mem:	Y',
    'Can get Mem:	Y',
    'Can set Channel:	E',
    'Can get Channel:	E',
    'Can ctl Mem/VFO:	Y',
    'Can Scan:	N',
    'Can get Info:	N' ,
    'Can get power2mW:	N',
    'Can get mW2power:	N',
    'Overall backend warnings: 0',
    'RPRT 0'
);

implementation

end.

